netapp_ontap.models.uri API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.uri`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class UriSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the Uri object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `fragment: str GET POST PATCH`

    The fragment field of the uri.

    Example: top

  `host: str GET POST PATCH`

    The host field of the uri.

    Example: 10.1.1.1

  `path: str GET POST PATCH`

    The path field of the uri.

    Example: /api/cluster

  `port: Size GET POST PATCH`

    The port field of the uri.

    Example: 433

  `query: str GET POST PATCH`

    The query field of the uri.

    Example: key1=value1

  `scheme: str GET POST PATCH`

    The scheme field of the uri.

    Example: https

  `userinfo: str GET POST PATCH`

    The userinfo field of the uri.

    Example: john.doe